@@ -8,7 +8,7 @@ import requests
 from packet import __version__
 
 
-class Error(Exception):  # pragma: no cover
+class Error(Exception):
     """Base exception class for this module"""
 
     def __init__(self, msg, cause=None):
@@ -25,6 +25,8 @@ class ResponseError(Error):
     def __init__(self, resp, data, exception=None):
         if not data:
             msg = "(empty response)"
+        elif not isinstance(data, dict):
+            msg = str(data)
         elif "error" in data:
             msg = data["error"]
         elif "errors" in data:
@@ -46,7 +48,7 @@ class JSONReadError(Error):
 
 class BaseAPI(object):
     """
-        Basic api class for
+    Basic api class for
     """
 
     def __init__(self, auth_token, consumer_token, user_agent=""):
@@ -94,7 +96,7 @@ class BaseAPI(object):
                 resp = requests.delete(url, headers=headers)
             elif type == "PATCH":
                 resp = requests.patch(url, headers=headers, data=json.dumps(params))
-            else:  # pragma: no cover
+            else:
                 raise Error(
                     "method type not recognized as one of GET, POST, DELETE or PATCH: %s"
                     % type
